# Arlunio 
![MIT License](https://img.shields.io/github/license/alcarney/arlunio.svg) [![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black) 
|   | **Stable** | **Snapshot** |
|:-------------:|----|----|
| **Docs** | | [![Documentation Status](https://github.com/swyddfa/arlunio/workflows/Docs%20Build/badge.svg?branch=develop)](https://www.arlun.io/docs/)|
| **Code** | [![Build Status](https://github.com/swyddfa/arlunio/workflows/Python%20Release/badge.svg?branch=master)](https://github.com/swyddfa/arlunio/workflows/Python%20Release/badge.svg?branch=master) [![codecov](https://codecov.io/gh/swyddfa/arlunio/branch/master/graph/badge.svg)](https://codecov.io/gh/swyddfa/arlunio)| [![Build Status](https://github.com/swyddfa/arlunio/workflows/Python%20Release/badge.svg?branch=develop)](https://github.com/swyddfa/arlunio/workflows/Python%20Release/badge.svg?branch=develop)[![codecov](https://codecov.io/gh/swyddfa/arlunio/branch/develop/graph/badge.svg)](https://codecov.io/gh/swyddfa/arlunio)|
| **PyPi** | [![PyPi Version](https://img.shields.io/pypi/v/arlunio.svg)](https://pypi.org/project/arlunio) [![PyPi Supported Versions](https://img.shields.io/pypi/pyversions/arlunio.svg)](https://pypi.org/project/arlunio)|


**Arlunio is in early development, while it is useable we cannot make any
stability guarantees.**

Arlunio is a Python library that allows you to create images and animations
powered by your imagination and a little mathematics. While mathematics is very
much at the core you do not have to be a mathematician to use it!


```python
import arlunio as ar

# Example coming soon!
```

## Installation

Arlunio is available for Python 3.6+ and can be installed using Pip:

```sh
$ pip install arlunio
```

Be sure to check out the [documentation](https://arlunio.readthedocs.io/en/latest/)
(under construction) for details on how to get started with arlunio.

## Contributing

Contributions are welcome! Just bear with us while contribution guidelines are
written up
